@@ -338,6 +338,10 @@ function judge($mark, $row, $judgingid)
 	system("mkdir -p '$workdir/compile'", $retval);
 	if ( $retval != 0 ) error("Could not create '$workdir/compile'");
 
+	// Make sure the workdir is accessible for the domjudge-run user.
+	// Will be revoked again after this run finished.
+	chmod($workdir, 0755);
+
 	if ( !chdir($workdir) ) error("Could not chdir to '$workdir'");
 
 	// Get the source code from the DB and store in local file(s)
@@ -391,10 +395,6 @@ function judge($mark, $row, $judgingid)
 		if ( $retval!=0 ) error("chroot script exited with exitcode $retval");
 	}
 
-	// Make sure the workdir is accessible for the domjudge-run user.	
-	// Will be revoked again after this run finished.
-	chmod ($workdir, 0755);
-
 	$final = FALSE;
 	foreach ( $testcases as $tc ) {
 
@@ -440,7 +440,7 @@ function judge($mark, $row, $judgingid)
 	system("mkdir -p '$programdir'", $retval);
 	if ( $retval!=0 ) error("Could not create directory '$programdir'");
 
-	system("cp -pPRl '$workdir'/compile/* '$programdir'", $retval);
+	system("cp -PR '$workdir'/compile/* '$programdir'", $retval);
 	if ( $retval!=0 ) error("Could not copy program to '$programdir'");
 
 	// do the actual test-run
@@ -492,9 +492,6 @@ function judge($mark, $row, $judgingid)
 
 	} // end: for each testcase
 
-	// revoke readablity for domjudge-run user to this workdir
-	chmod($workdir, 0700);
-
 	// Optionally destroy chroot environment
 	if ( USE_CHROOT && CHROOT_SCRIPT ) {
 		logmsg(LOG_INFO, "executing chroot script: '".CHROOT_SCRIPT." stop'");
@@ -504,6 +501,9 @@ function judge($mark, $row, $judgingid)
 
 	} // end: if no compile-error
 
+	// revoke readablity for domjudge-run user to this workdir
+	chmod($workdir, 0700);
+
 	if ( $result==NULL ) error("No final result obtained");
 
 	// Store judging endtime, result was already stored.
