@@ -276,6 +276,7 @@ Run COMMAND with restrictions.\n\
       --version          output version information and exit\n");
 	printf("\n\
 Note that root privileges are needed for the `root' and `user' options.\n\
+The COMMAND path is relative to the changed ROOT directory if specified.\n\
 When run setuid without the `user' option, the user ID is set to the\n\
 real user ID.\n");
 	exit(0);
@@ -341,15 +342,15 @@ void output_cgroup_stats()
 		error(0,"cgroup_new_cgroup");
 	}
 	if ((ret = cgroup_get_cgroup(cg)) != 0) {
-		error(0,"get cgroup information - %s(%d)", cgroup_strerror(ret), ret);
+		error(0,"get cgroup information: %s(%d)", cgroup_strerror(ret), ret);
 	}
 	cg_controller = cgroup_get_controller(cg, "memory");
 	ret = cgroup_get_value_int64(cg_controller, "memory.memsw.max_usage_in_bytes", &max_usage);
 	if ( ret!=0 ) {
-		error(0,"get cgroup value - %s(%d)", cgroup_strerror(ret), ret);
+		error(0,"get cgroup value: %s(%d)", cgroup_strerror(ret), ret);
 	}
 
-	fprintf(stderr, "Total memory used: %" PRId64 " kB\n", max_usage/1024);
+	verbose("total memory used: %" PRId64 " kB", max_usage/1024);
 
 	cgroup_free(&cg);
 }
@@ -371,9 +372,9 @@ void cgroup_create()
 	cgroup_add_value_int64(cg_controller, "memory.limit_in_bytes", memsize);
 	cgroup_add_value_int64(cg_controller, "memory.memsw.limit_in_bytes", memsize);
 
-	/* Set up cpu restrictions; we pin the task to a specific set of cpus,
-	   based on the environment variable CPUSET. We also give it exclusive
-	   access to those cores, and set no limits on memory nodes */
+	/* Set up cpu restrictions; we pin the task to a specific set of
+	   cpus. We also give it exclusive access to those cores, and set
+	   no limits on memory nodes */
 	if ( cpuset!=NULL && strlen(cpuset)>0 ) {
 		cg_controller = cgroup_add_controller(cg, "cpuset");
 		/* To make a cpuset exclusive, some additional setup outside of domjudge is
@@ -382,13 +383,13 @@ void cgroup_create()
 		cgroup_add_value_string(cg_controller, "cpuset.mems", "0");
 		cgroup_add_value_string(cg_controller, "cpuset.cpus", cpuset);
 	} else {
-		fprintf(stderr, "CPUSET undefined\n");
+		verbose("cpuset undefined");
 	}
 
 	/* Perform the actual creation of the cgroup */
 	ret = cgroup_create_cgroup(cg, 1);
 	if ( ret!=0 ) {
-		error(0,"creating cgroup - %s(%d)", cgroup_strerror(ret), ret);
+		error(0,"creating cgroup: %s(%d)", cgroup_strerror(ret), ret);
 	}
 
 	cgroup_free(&cg);
@@ -405,13 +406,13 @@ void cgroup_attach()
 	}
 	ret = cgroup_get_cgroup(cg);
 	if ( ret!=0 ) {
-		error(0,"get cgroup information - %s(%d)", cgroup_strerror(ret), ret);
+		error(0,"get cgroup information: %s(%d)", cgroup_strerror(ret), ret);
 	}
 
 	/* Attach task to the cgroup */
 	ret = cgroup_attach_task(cg);
 	if ( ret!=0 ) {
-		error(0,"attach task to cgroup - %s(%d)", cgroup_strerror(ret), ret);
+		error(0,"attach task to cgroup: %s(%d)", cgroup_strerror(ret), ret);
 	}
 
 	cgroup_free(&cg);
@@ -428,12 +429,12 @@ void cgroup_delete()
 	}
 	ret = cgroup_get_cgroup(cg);
 	if ( ret!=0 ) {
-		error(0,"get cgroup information - %s(%d)", cgroup_strerror(ret), ret);
+		error(0,"get cgroup information: %s(%d)", cgroup_strerror(ret), ret);
 	}
 	/* Clean up our cgroup */
 	ret = cgroup_delete_cgroup(cg, 1);
 	if ( ret!=0 ) {
-		error(0,"deleting cgroup - %s(%d)", cgroup_strerror(ret), ret);
+		error(0,"deleting cgroup: %s(%d)", cgroup_strerror(ret), ret);
 	}
 	cgroup_free(&cg);
 }
@@ -445,8 +446,16 @@ void terminate(int sig)
 
 	/* Reset signal handlers to default */
 	sigact.sa_handler = SIG_DFL;
-	if ( sigaction(SIGTERM,&sigact,NULL)!=0 ) warning("error restoring signal handler");
-	if ( sigaction(SIGALRM,&sigact,NULL)!=0 ) warning("error restoring signal handler");
+	sigact.sa_flags = 0;
+	if ( sigemptyset(&sigact.sa_mask)!=0 ) {
+		warning("could not initialize signal mask");
+	}
+	if ( sigaction(SIGTERM,&sigact,NULL)!=0 ) {
+		warning("could not restore signal handler");
+	}
+	if ( sigaction(SIGALRM,&sigact,NULL)!=0 ) {
+		warning("could not restore signal handler");
+	}
 
 	if ( sig==SIGALRM ) {
 		warning("timelimit exceeded (wall time): aborting command");
@@ -585,7 +594,7 @@ void setrestrictions()
 	if ( use_root ) {
 		/* Small security issue: when running setuid-root, people can find
 		   out which directories exist from error message. */
-		if ( chdir(rootdir) ) error(errno,"cannot chdir to `%s'",rootdir);
+		if ( chdir(rootdir)!=0 ) error(errno,"cannot chdir to `%s'",rootdir);
 
 		/* Get absolute pathname of rootdir, by reading it. */
 		if ( getcwd(cwd,PATH_MAX)==NULL ) error(errno,"cannot get directory");
@@ -605,7 +614,9 @@ void setrestrictions()
 		}
 		free(path);
 
-		if ( chroot(".") ) error(errno,"cannot change root to `%s'",cwd);
+		if ( chroot(".")!=0 ) error(errno,"cannot change root to `%s'",cwd);
+		/* Just to make sure and satisfy Coverity scan: */
+		if ( chdir("/")!=0 ) error(errno,"cannot chdir to `/' in chroot");
 		verbose("using root-directory `%s'",cwd);
 	}
 
@@ -720,7 +731,7 @@ int main(int argc, char **argv)
 			#ifdef USE_CGROUPS
 				cpuset = optarg;
 			#else
-				error(0,"This option is only supported when compiled with cgroup support.");
+				error(0,"option `-P' is only supported when compiled with cgroup support.");
 			#endif
 			break;
 		case 'c': /* no-core option */
