@@ -54,6 +54,57 @@ function check_problem($data, $keydata = null)
 	if ( ! preg_match ( ID_REGEX, $id ) ) {
 		ch_error("Problem ID may only contain characters " . IDENTIFIER_CHARS . ".");
 	}
+
+	if ( !empty($_FILES['data']['name'][0]['problemtext']) ) {
+		$origname = $_FILES['data']['name'][0]['problemtext'];
+		$tempname = $_FILES['data']['tmp_name'][0]['problemtext'];
+		if ( strrpos($origname,'.')!==FALSE ) {
+			$ext = substr($origname,strrpos($origname,'.')+1);
+			if ( in_array($ext, array('txt','html','pdf')) ) {
+				$data['problemtext_type'] = $ext;
+			}
+		}
+		// These functions only exist in PHP >= 5.3.0.
+		if ( !isset($data['problemtext_type']) &&
+		     function_exists("finfo_open") ) {
+			$finfo = finfo_open(FILEINFO_MIME);
+
+			list($type, $enc) = explode('; ', finfo_file($finfo, $tempname));
+
+			finfo_close($finfo);
+
+			switch ( $type ) {
+			case 'application/pdf':
+				$data['problemtext_type'] = 'pdf';
+				break;
+			case 'text/html':
+				$data['problemtext_type'] = 'html';
+				break;
+			case 'text/plain':
+				$data['problemtext_type'] = 'txt';
+				break;
+			}
+		}
+		if ( !isset($data['problemtext_type']) ) {
+			ch_error("Problem statement has unknown file type.");
+		}
+	}
+	if ( !empty($data['problemtext']) &&
+	     !isset($data['problemtext_type']) ) {
+		ch_error("Problem statement has unknown file type.");
+	}
+
+	return $data;
+}
+
+function check_judgehost($data, $keydata = null)
+{
+	$id = (isset($data['hostname']) ? $data['hostname'] : $keydata['hostname']);
+
+	if ( ! preg_match("/^[A-Za-z0-9_\-.]*$/", $id) ) {
+		ch_error("Judgehost has invalid hostname.");
+	}
+
 	return $data;
 }
 
