@@ -4,8 +4,6 @@
  * Functions to create syntax highlighted views of source code,
  * supporting different external formatters.
  *
- * $Id: scoreboard.php 2641 2009-04-09 21:46:39Z kink $
- *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
  */
@@ -22,7 +20,7 @@ function highlight ($source, $ext)
 	if ( !isset($lib) ) {
 		$lib = highlighter_init();
 	}
-	call_user_func('highlight_'.$lib, $source, $ext);
+	return call_user_func('highlight_'.$lib, $source, $ext);
 }
 
 /**
@@ -48,13 +46,9 @@ function highlighter_init ()
 	// marginally more secure when including files. Doesn't hurt.
 	define ('GESHI_SECURITY_PARANOID', true);
 
-	// Add LIBWWWDIR to include path for locally installed libs.
-	// Text_Highlighter needs this since it specifies relative paths.
-	set_include_path(get_include_path() . PATH_SEPARATOR . LIBWWWDIR);
-
 	$PATHS = array();
 	$PATHS['geshi'] = array (
-		'geshi.php',
+		'geshi/geshi.php',
 		'/usr/share/php-geshi/geshi.php' );
 	$PATHS['texthighlighter'] = array (
 		'Text/Highlighter.php' );
@@ -76,14 +70,24 @@ function highlighter_init ()
  */
 function highlight_geshi ($source, $ext)
 {
-	$geshi = new Geshi ($source, $ext);
+	switch (strtolower($ext)) {
+	case 'hs':  $lang = 'haskell'; break;
+	case 'pas': $lang = 'pascal';  break;
+	case 'pl':  $lang = 'perl';    break;
+	case 'py':  $lang = 'python';  break;
+	case 'sh':  $lang = 'bash';    break;
+	default:
+		$lang = $ext;
+	}
+
+	$geshi = new Geshi ($source, $lang);
 	$geshi->enable_line_numbers(GESHI_FANCY_LINE_NUMBERS);
 	// TODO: make output use more CSS and less <font>
 	if ( $geshi->error()===FALSE ) {
-		echo $geshi->parse_code();
-	} else {
-		highlight_native($source, $ext);
+		return $geshi->parse_code();
 	}
+	
+	return highlight_native($source, $ext);
 }
 
 /**
@@ -106,10 +110,10 @@ function highlight_texthighlighter ($source, $ext)
 
 	if ( !PEAR::isError($hl) ) {
 		$hl->setRenderer($renderer);
-		echo $hl->highlight($source);
-	} else {
-		highlight_native($source, $ext);
+		return $hl->highlight($source);
 	}
+
+	return highlight_native($source, $ext);
 }
 
 /**
@@ -119,13 +123,13 @@ function highlight_texthighlighter ($source, $ext)
 function highlight_native ($source, $ext)
 {
 	$sourcelines = explode("\n", $source);
-	echo '<pre class="output_text">';
+	$ret = '<pre class="output_text">';
 	$i = 1;
 	$lnlen = strlen(count($sourcelines));
 	foreach ($sourcelines as $line ) {
-		echo "<span class=\"lineno\">" . str_pad($i, $lnlen, ' ', STR_PAD_LEFT) .
+		$ret .= "<span class=\"lineno\">" . str_pad($i, $lnlen, ' ', STR_PAD_LEFT) .
 			"</span>  " . htmlspecialchars($line) . "\n";
 		$i++;
 	}
-	echo "</pre>\n\n";
+	return $ret . "</pre>\n\n";
 }
