@@ -2,6 +2,7 @@
    Checktestdata -- check testdata according to specification.
    Copyright (C) 2008-2012 Jan Kuipers
    Copyright (C) 2009-2012 Jaap Eldering (eldering@a-eskwadraat.nl).
+   Copyright (C) 2012 Tobias Werth (werth@cs.fau.de)
 
    For detailed information, see libchecktestdata.
 
@@ -32,7 +33,7 @@
 using namespace std;
 
 #define PROGRAM "checktestdata"
-#define AUTHORS "Jan Kuipers, Jaap Eldering"
+#define AUTHORS "Jan Kuipers, Jaap Eldering, Tobias Werth"
 #define VERSION DOMJUDGE_VERSION "/" REVISION
 
 const int exit_testdata = 1;
@@ -44,6 +45,8 @@ int show_version;
 
 struct option const long_opts[] = {
 	{"whitespace-ok", no_argument, NULL,         'w'},
+	{"generate",no_argument,       NULL,         'g'},
+	{"preset",  required_argument, NULL,         'p'},
 	{"debug",   no_argument,       NULL,         'd'},
 	{"quiet",   no_argument,       NULL,         'q'},
 	{"help",    no_argument,       &show_help,    1 },
@@ -65,12 +68,15 @@ void usage()
 {
         printf(
 "Usage: %s [OPTION]... PROGRAM [TESTDATA]\n"
-"Check TESTDATA according to specification in PROGRAM file.\n"
-"If TESTDATA is '-' or not specified, read from stdin.\n"
+"Check (or generate) TESTDATA according to specification in PROGRAM file.\n"
+"If TESTDATA is '-' or not specified, read from stdin (or write to stdout).\n"
 "\n"
 "  -w, --whitespace-ok  whitespace changes are accepted, including heading\n"
 "                         and trailing whitespace, but not newlines;\n"
 "                         be careful: extra whitespace matches greedily!\n"
+"  -g, --generate       don't check but generate (random) testdata\n"
+"  -p, --preset=<name>=<value>[,...]\n"
+"                       preset variable(s) <name> when generating testdata\n"
 "  -d, --debug          enable extra debugging output\n"
 "  -q, --quiet          don't display testdata error messages: test exitcode\n"
 "      --help           display this help and exit\n"
@@ -81,8 +87,10 @@ void usage()
 int main(int argc, char **argv)
 {
 	int whitespace_ok;
+	int generate;
 	int debugging;
 	int quiet;
+	string presets;
 
 	int opt;
 
@@ -90,15 +98,21 @@ int main(int argc, char **argv)
 
 	/* Parse command-line options */
 	whitespace_ok = 0;
-	debugging = quiet = show_help = show_version = 0;
+	generate = debugging = quiet = show_help = show_version = 0;
 	opterr = 0;
-	while ( (opt = getopt_long(argc,argv,"+wdq",long_opts,(int *) 0))!=-1 ) {
+	while ( (opt = getopt_long(argc,argv,"+wgp:dq",long_opts,(int *) 0))!=-1 ) {
 		switch ( opt ) {
 		case 0:   /* long-only option */
 			break;
 		case 'w':
 			whitespace_ok = 1;
 			break;
+		case 'g':
+			generate = 1;
+			break;
+		case 'p':
+			presets = optarg;
+			break;
 		case 'd':
 			debugging = 1;
 			break;
@@ -107,10 +121,10 @@ int main(int argc, char **argv)
 			break;
 		case ':': /* getopt error */
 		case '?':
-			printf("unknown option or missing argument `%c'",optopt);
+			printf("Error: unknown option or missing argument `%c'.\n",optopt);
 			exit(exit_failure);
 		default:
-			printf("getopt returned character code `%c' ??",(char)opt);
+			printf("Error: getopt returned character code `%c' ??\n",(char)opt);
 			exit(exit_failure);
 		}
 	}
@@ -128,7 +142,7 @@ int main(int argc, char **argv)
 	char *progfile = argv[optind];
 	ifstream prog(progfile);
 	if ( prog.fail() ) {
-		cerr << "error opening " << progfile << endl;
+		cerr << "Error opening '" << progfile << "'.\n";
 		exit(exit_failure);
 	}
 
@@ -139,28 +153,53 @@ int main(int argc, char **argv)
 	if (quiet        ) options |= opt_quiet;
 
 	// Check for testdata file and check syntax
-	bool testdata_ok;
+	bool testdata_ok = 0;
+
+	init_checktestdata(prog, options);
+
+	// Parse presets after initialization to have debugging available
+	if ( !parse_preset_list(presets) ) {
+		printf("Error parsing preset variable list.\n");
+		exit(exit_failure);
+	}
 
 	if ( argc<=optind+1 ) {
-		testdata_ok = checksyntax(prog, cin, options);
+		if ( generate ) {
+			gentestdata(cout);
+		} else {
+			testdata_ok = checksyntax(cin);
+		}
 	} else {
-		char *datafile = argv[optind+1];
-		ifstream fin(datafile);
-		if ( fin.fail() ) {
-			cerr << "error opening " << datafile << endl;
-			exit(exit_failure);
+		if ( generate ) {
+			char *datafile = argv[optind+1];
+			ofstream fout(datafile);
+			if ( fout.fail() ) {
+				cerr << "Error opening '" << datafile << "'.\n";
+				exit(exit_failure);
+			}
+			gentestdata(fout);
+			fout.close();
+		} else {
+			char *datafile = argv[optind+1];
+			ifstream fin(datafile);
+			if ( fin.fail() ) {
+				cerr << "Error opening '" << datafile << "'.\n";
+				exit(exit_failure);
+			}
+			testdata_ok = checksyntax(fin);
+			fin.close();
 		}
-		testdata_ok = checksyntax(prog, fin, options);
-		fin.close();
 	}
 
 	prog.close();
 
-	if ( !testdata_ok) {
-		exit(exit_testdata);
-	}
+	if ( !generate ) {
+		if ( !testdata_ok ) {
+			exit(exit_testdata);
+		}
 
-	if ( !quiet ) cout << "testdata ok!" << endl;
+		if ( !quiet ) cout << "testdata ok!" << endl;
+	}
 
 	return 0;
 }
