@@ -37,16 +37,16 @@ CREATE TABLE `balloon` (
 -- Table structure for table `clarification`
 --
 CREATE TABLE `clarification` (
-  `clarid` int(4) unsigned NOT NULL auto_increment COMMENT 'Unique ID',
+  `clarid` int(4) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Unique ID',
   `cid` int(4) unsigned NOT NULL COMMENT 'Contest ID',
-  `respid` int(4) unsigned default NULL COMMENT 'In reply to clarification ID',
+  `respid` int(4) unsigned DEFAULT NULL COMMENT 'In reply to clarification ID',
   `submittime` datetime NOT NULL COMMENT 'Time sent',
-  `sender` varchar(15) default NULL COMMENT 'Team login, null means jury',
-  `recipient` varchar(15) default NULL COMMENT 'Team login, null means to jury or to all',
-  `jury_member` varchar(15) default NULL COMMENT 'Name of jury member who answered this',
-  `probid` varchar(8) default NULL COMMENT 'Problem associated to this clarification',
+  `sender` varchar(15) DEFAULT NULL COMMENT 'Team login, null means jury',
+  `recipient` varchar(15) DEFAULT NULL COMMENT 'Team login, null means to jury or to all',
+  `jury_member` varchar(15) DEFAULT NULL COMMENT 'Name of jury member who answered this',
+  `probid` varchar(8) DEFAULT NULL COMMENT 'Problem associated to this clarification',
   `body` longtext NOT NULL COMMENT 'Clarification text',
-  `answered` tinyint(1) unsigned NOT NULL default '0' COMMENT 'Has been answered by jury?',
+  `answered` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Has been answered by jury?',
   PRIMARY KEY  (`clarid`),
   KEY `cid` (`cid`,`answered`,`submittime`),
   KEY `respid` (`respid`),
@@ -64,30 +64,29 @@ CREATE TABLE `configuration` (
   `configid` int(4) NOT NULL AUTO_INCREMENT COMMENT 'Configuration ID',
   `name` varchar(25) NOT NULL COMMENT 'Name of the configuration variable',
   `value` longtext NOT NULL COMMENT 'Content of the configuration variable',
-  `type` varchar(25) default NULL COMMENT 'Type of the value (metatype for use in the webinterface)',
-  `description` varchar(255) default NULL COMMENT 'Description for in the webinterface',
+  `type` varchar(25) DEFAULT NULL COMMENT 'Type of the value (metatype for use in the webinterface)',
+  `description` varchar(255) DEFAULT NULL COMMENT 'Description for in the webinterface',
   PRIMARY KEY (`configid`),
   KEY `name` (`name`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Global configuration variables';
 
-
 --
 -- Table structure for table `contest`
 --
 
 CREATE TABLE `contest` (
-  `cid` int(4) unsigned NOT NULL auto_increment COMMENT 'Contest ID',
+  `cid` int(4) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Contest ID',
   `contestname` varchar(255) NOT NULL COMMENT 'Descriptive name',
   `activatetime` datetime NOT NULL COMMENT 'Time contest becomes visible in team/public views',
   `starttime` datetime NOT NULL COMMENT 'Time contest starts, submissions accepted',
-  `freezetime` datetime default NULL COMMENT 'Time scoreboard is frozen',
+  `freezetime` datetime DEFAULT NULL COMMENT 'Time scoreboard is frozen',
   `endtime` datetime NOT NULL COMMENT 'Time after which no more submissions are accepted',
-  `unfreezetime` datetime default NULL COMMENT 'Unfreeze a frozen scoreboard at this time',
+  `unfreezetime` datetime DEFAULT NULL COMMENT 'Unfreeze a frozen scoreboard at this time',
   `activatetime_string` varchar(20) NOT NULL COMMENT 'Authoritative absolute or relative string representation of activatetime',
-  `freezetime_string` varchar(20) default NULL COMMENT 'Authoritative absolute or relative string representation of freezetime',
+  `freezetime_string` varchar(20) DEFAULT NULL COMMENT 'Authoritative absolute or relative string representation of freezetime',
   `endtime_string` varchar(20) NOT NULL COMMENT 'Authoritative absolute or relative string representation of endtime',
-  `unfreezetime_string` varchar(20) default NULL COMMENT 'Authoritative absolute or relative string representation of unfreezetrime',
-  `enabled` tinyint(1) unsigned NOT NULL default '1' COMMENT 'Whether this contest can be active',
+  `unfreezetime_string` varchar(20) DEFAULT NULL COMMENT 'Authoritative absolute or relative string representation of unfreezetrime',
+  `enabled` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'Whether this contest can be active',
   PRIMARY KEY (`cid`),
   KEY `cid` (`cid`,`enabled`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Contests that will be run with this install';
@@ -97,15 +96,15 @@ CREATE TABLE `contest` (
 --
 
 CREATE TABLE `event` (
-  `eventid` int(4) unsigned NOT NULL auto_increment COMMENT 'Unique ID',
+  `eventid` int(4) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Unique ID',
   `eventtime` datetime NOT NULL COMMENT 'When the event occurred',
   `cid` int(4) unsigned NOT NULL COMMENT 'Contest ID',
-  `clarid` int(4) unsigned default NULL COMMENT 'Clarification ID',
-  `langid` varchar(8) default NULL COMMENT 'Language ID',
-  `probid` varchar(8) default NULL COMMENT 'Problem ID',
-  `submitid` int(4) unsigned default NULL COMMENT 'Submission ID',
-  `judgingid` int(4) unsigned default NULL COMMENT 'Judging ID',
-  `teamid` varchar(15) default NULL COMMENT 'Team login',
+  `clarid` int(4) unsigned DEFAULT NULL COMMENT 'Clarification ID',
+  `langid` varchar(8) DEFAULT NULL COMMENT 'Language ID',
+  `probid` varchar(8) DEFAULT NULL COMMENT 'Problem ID',
+  `submitid` int(4) unsigned DEFAULT NULL COMMENT 'Submission ID',
+  `judgingid` int(4) unsigned DEFAULT NULL COMMENT 'Judging ID',
+  `teamid` varchar(15) DEFAULT NULL COMMENT 'Team login',
   `description` longtext NOT NULL COMMENT 'Event description',
   PRIMARY KEY  (`eventid`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Log of all events during a contest';
@@ -116,8 +115,8 @@ CREATE TABLE `event` (
 
 CREATE TABLE `judgehost` (
   `hostname` varchar(50) NOT NULL COMMENT 'Resolvable hostname of judgehost',
-  `active` tinyint(1) unsigned NOT NULL default '1' COMMENT 'Should this host take on judgings?',
-  `polltime` datetime default NULL COMMENT 'Time of last poll by autojudger',
+  `active` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'Should this host take on judgings?',
+  `polltime` datetime DEFAULT NULL COMMENT 'Time of last poll by autojudger',
   PRIMARY KEY  (`hostname`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Hostnames of the autojudgers';
 
@@ -126,19 +125,19 @@ CREATE TABLE `judgehost` (
 --
 
 CREATE TABLE `judging` (
-  `judgingid` int(4) unsigned NOT NULL auto_increment COMMENT 'Unique ID',
-  `cid` int(4) unsigned NOT NULL default '0' COMMENT 'Contest ID',
+  `judgingid` int(4) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Unique ID',
+  `cid` int(4) unsigned NOT NULL DEFAULT '0' COMMENT 'Contest ID',
   `submitid` int(4) unsigned NOT NULL COMMENT 'Submission ID being judged',
   `starttime` datetime NOT NULL COMMENT 'Time judging started',
-  `endtime` datetime default NULL COMMENT 'Time judging ended, null = still busy',
-  `judgehost` varchar(50) default NULL COMMENT 'Judgehost that performed the judging',
-  `result` varchar(25) default NULL COMMENT 'Result string as defined in config.php',
-  `verified` tinyint(1) unsigned NOT NULL default '0' COMMENT 'Result verified by jury member?',
-  `jury_member` varchar(15) default NULL COMMENT 'Name of jury member who verified this',
+  `endtime` datetime DEFAULT NULL COMMENT 'Time judging ended, null = still busy',
+  `judgehost` varchar(50) DEFAULT NULL COMMENT 'Judgehost that performed the judging',
+  `result` varchar(25) DEFAULT NULL COMMENT 'Result string as defined in config.php',
+  `verified` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Result verified by jury member?',
+  `jury_member` varchar(15) DEFAULT NULL COMMENT 'Name of jury member who verified this',
   `verify_comment` varchar(255) DEFAULT NULL COMMENT 'Optional additional information provided by the verifier',
-  `valid` tinyint(1) unsigned NOT NULL default '1' COMMENT 'Old judging is marked as invalid when rejudging',
+  `valid` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'Old judging is marked as invalid when rejudging',
   `output_compile` longblob COMMENT 'Output of the compiling the program',
-  `seen` tinyint(1) unsigned NOT NULL default '0' COMMENT 'Whether the team has seen this judging',
+  `seen` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Whether the team has seen this judging',
   PRIMARY KEY  (`judgingid`),
   KEY `submitid` (`submitid`),
   KEY `judgehost` (`judgehost`),
@@ -153,10 +152,10 @@ CREATE TABLE `judging` (
 --
 
 CREATE TABLE `judging_run` (
-  `runid` int(4) unsigned NOT NULL auto_increment COMMENT 'Unique identifier',
+  `runid` int(4) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Unique identifier',
   `judgingid` int(4) unsigned NOT NULL COMMENT 'Judging ID',
   `testcaseid` int(4) unsigned NOT NULL COMMENT 'Testcase ID',
-  `runresult` varchar(25) default NULL COMMENT 'Result of this run, NULL if not finished yet',
+  `runresult` varchar(25) DEFAULT NULL COMMENT 'Result of this run, NULL if not finished yet',
   `runtime` float DEFAULT NULL COMMENT 'Submission running time on this testcase',
   `output_run` longblob COMMENT 'Output of running the program',
   `output_diff` longblob COMMENT 'Diffing the program output and testcase output',
@@ -176,9 +175,9 @@ CREATE TABLE `judging_run` (
 CREATE TABLE `language` (
   `langid` varchar(8) NOT NULL COMMENT 'Unique ID (string), used for source file extension',
   `name` varchar(255) NOT NULL COMMENT 'Descriptive language name',
-  `allow_submit` tinyint(1) unsigned NOT NULL default '1' COMMENT 'Are submissions accepted in this language?',
-  `allow_judge` tinyint(1) unsigned NOT NULL default '1' COMMENT 'Are submissions in this language judged?',
-  `time_factor` float NOT NULL default '1' COMMENT 'Language-specific factor multiplied by problem run times',
+  `allow_submit` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'Are submissions accepted in this language?',
+  `allow_judge` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'Are submissions in this language judged?',
+  `time_factor` float NOT NULL DEFAULT '1' COMMENT 'Language-specific factor multiplied by problem run times',
   PRIMARY KEY  (`langid`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Programming languages in which teams can submit solutions';
 
@@ -190,12 +189,14 @@ CREATE TABLE `problem` (
   `probid` varchar(8) NOT NULL COMMENT 'Unique ID (string)',
   `cid` int(4) unsigned NOT NULL COMMENT 'Contest ID',
   `name` varchar(255) NOT NULL COMMENT 'Descriptive name',
-  `allow_submit` tinyint(1) unsigned NOT NULL default '0' COMMENT 'Are submissions accepted for this problem?',
-  `allow_judge` tinyint(1) unsigned NOT NULL default '1' COMMENT 'Are submissions for this problem judged?',
-  `timelimit` int(4) unsigned NOT NULL default '0' COMMENT 'Maximum run time for this problem',
-  `special_run` varchar(25) default NULL COMMENT 'Script to run submissions for this problem',
-  `special_compare` varchar(25) default NULL COMMENT 'Script to compare problem and jury output for this problem',
-  `color` varchar(25) default NULL COMMENT 'Balloon colour to display on the scoreboard',
+  `allow_submit` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Are submissions accepted for this problem?',
+  `allow_judge` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'Are submissions for this problem judged?',
+  `timelimit` int(4) unsigned NOT NULL DEFAULT '0' COMMENT 'Maximum run time for this problem',
+  `special_run` varchar(25) DEFAULT NULL COMMENT 'Script to run submissions for this problem',
+  `special_compare` varchar(25) DEFAULT NULL COMMENT 'Script to compare problem and jury output for this problem',
+  `color` varchar(25) DEFAULT NULL COMMENT 'Balloon colour to display on the scoreboard',
+  `problemtext` longblob COMMENT 'Problem text in HTML/PDF/ASCII',
+  `problemtext_type` varchar(4) DEFAULT NULL COMMENT 'File type of problem text',
   PRIMARY KEY  (`probid`),
   KEY `cid` (`cid`),
   CONSTRAINT `problem_ibfk_1` FOREIGN KEY (`cid`) REFERENCES `contest` (`cid`) ON DELETE CASCADE
@@ -209,10 +210,10 @@ CREATE TABLE `scoreboard_jury` (
   `cid` int(4) unsigned NOT NULL COMMENT 'Contest ID',
   `teamid` varchar(15) NOT NULL COMMENT 'Team login',
   `probid` varchar(8) NOT NULL COMMENT 'Problem ID',
-  `submissions` int(4) unsigned NOT NULL default '0' COMMENT 'Number of submissions made',
-  `pending` int(4) NOT NULL default '0' COMMENT 'Number of submissions pending judgement',
-  `totaltime` int(4) unsigned NOT NULL default '0' COMMENT 'Total time spent',
-  `is_correct` tinyint(1) unsigned NOT NULL default '0' COMMENT 'Has there been a correct submission?',
+  `submissions` int(4) unsigned NOT NULL DEFAULT '0' COMMENT 'Number of submissions made',
+  `pending` int(4) NOT NULL DEFAULT '0' COMMENT 'Number of submissions pending judgement',
+  `totaltime` int(4) unsigned NOT NULL DEFAULT '0' COMMENT 'Total time spent',
+  `is_correct` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Has there been a correct submission?',
   PRIMARY KEY  (`cid`,`teamid`,`probid`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Scoreboard cache (jury version)';
 
@@ -224,10 +225,10 @@ CREATE TABLE `scoreboard_public` (
   `cid` int(4) unsigned NOT NULL COMMENT 'Contest ID',
   `teamid` varchar(15) NOT NULL COMMENT 'Team login',
   `probid` varchar(8) NOT NULL COMMENT 'Problem ID',
-  `submissions` int(4) unsigned NOT NULL default '0' COMMENT 'Number of submissions made',
-  `pending` int(4) NOT NULL default '0' COMMENT 'Number of submissions pending judgement',
-  `totaltime` int(4) unsigned NOT NULL default '0' COMMENT 'Total time spent',
-  `is_correct` tinyint(1) unsigned NOT NULL default '0' COMMENT 'Has there been a correct submission?',
+  `submissions` int(4) unsigned NOT NULL DEFAULT '0' COMMENT 'Number of submissions made',
+  `pending` int(4) NOT NULL DEFAULT '0' COMMENT 'Number of submissions pending judgement',
+  `totaltime` int(4) unsigned NOT NULL DEFAULT '0' COMMENT 'Total time spent',
+  `is_correct` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Has there been a correct submission?',
   PRIMARY KEY  (`cid`,`teamid`,`probid`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Scoreboard cache (public/team version)';
 
@@ -236,16 +237,16 @@ CREATE TABLE `scoreboard_public` (
 --
 
 CREATE TABLE `submission` (
-  `submitid` int(4) unsigned NOT NULL auto_increment COMMENT 'Unique ID',
-  `origsubmitid` int(4) unsigned default NULL COMMENT 'If set, specifies original submission in case of edit/resubmit',
+  `submitid` int(4) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Unique ID',
+  `origsubmitid` int(4) unsigned DEFAULT NULL COMMENT 'If set, specifies original submission in case of edit/resubmit',
   `cid` int(4) unsigned NOT NULL COMMENT 'Contest ID',
   `teamid` varchar(15) NOT NULL COMMENT 'Team login',
   `probid` varchar(8) NOT NULL COMMENT 'Problem ID',
   `langid` varchar(8) NOT NULL COMMENT 'Language ID',
   `submittime` datetime NOT NULL COMMENT 'Time submitted',
-  `judgehost` varchar(50) default NULL COMMENT 'Current/last judgehost judging this submission',
-  `judgemark` varchar(255) default NULL COMMENT 'Unique identifier for taking a submission by a judgehost',
-  `valid` tinyint(1) unsigned NOT NULL default '1' COMMENT 'If false ignore this submission in all scoreboard calculations',
+  `judgehost` varchar(50) DEFAULT NULL COMMENT 'Current/last judgehost judging this submission',
+  `judgemark` varchar(255) DEFAULT NULL COMMENT 'Unique identifier for taking a submission by a judgehost',
+  `valid` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'If false ignore this submission in all scoreboard calculations',
   PRIMARY KEY  (`submitid`),
   UNIQUE KEY `judgemark` (`judgemark`),
   KEY `teamid` (`cid`,`teamid`),
@@ -287,16 +288,16 @@ CREATE TABLE `submission_file` (
 CREATE TABLE `team` (
   `login` varchar(15) NOT NULL COMMENT 'Team login name',
   `name` varchar(255) CHARACTER SET utf8 COLLATE utf8_bin NOT NULL COMMENT 'Team name',
-  `categoryid` int(4) unsigned NOT NULL default '0' COMMENT 'Team category ID',
-  `affilid` varchar(10) default NULL COMMENT 'Team affiliation ID',
-  `authtoken` varchar(255) default NULL COMMENT 'Identifying token for this team',
+  `categoryid` int(4) unsigned NOT NULL DEFAULT '0' COMMENT 'Team category ID',
+  `affilid` varchar(10) DEFAULT NULL COMMENT 'Team affiliation ID',
+  `authtoken` varchar(255) DEFAULT NULL COMMENT 'Identifying token for this team',
   `enabled` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'Whether the team is visible and operational',
   `members` longtext COMMENT 'Team member names (freeform)',
-  `room` varchar(15) default NULL COMMENT 'Physical location of team',
+  `room` varchar(15) DEFAULT NULL COMMENT 'Physical location of team',
   `comments` longtext COMMENT 'Comments about this team',
-  `judging_last_started` datetime default NULL COMMENT 'Start time of last judging for priorization',
-  `teampage_first_visited` datetime default NULL COMMENT 'Time of first teampage view',
-  `hostname` varchar(255) default NULL COMMENT 'Teampage first visited from this address',
+  `judging_last_started` datetime DEFAULT NULL COMMENT 'Start time of last judging for priorization',
+  `teampage_first_visited` datetime DEFAULT NULL COMMENT 'Time of first teampage view',
+  `hostname` varchar(255) DEFAULT NULL COMMENT 'Teampage first visited from this address',
   PRIMARY KEY  (`login`),
   UNIQUE KEY `name` (`name`),
   KEY `affilid` (`affilid`),
@@ -312,7 +313,7 @@ CREATE TABLE `team` (
 CREATE TABLE `team_affiliation` (
   `affilid` varchar(10) NOT NULL COMMENT 'Unique ID',
   `name` varchar(255) NOT NULL COMMENT 'Descriptive name',
-  `country` char(3) default NULL COMMENT 'ISO 3166-1 alpha-3 country code',
+  `country` char(3) DEFAULT NULL COMMENT 'ISO 3166-1 alpha-3 country code',
   `comments` longtext COMMENT 'Comments',
   PRIMARY KEY  (`affilid`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Affilitations for teams (e.g.: university, company)';
@@ -322,11 +323,11 @@ CREATE TABLE `team_affiliation` (
 --
 
 CREATE TABLE `team_category` (
-  `categoryid` int(4) unsigned NOT NULL auto_increment COMMENT 'Unique ID',
+  `categoryid` int(4) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Unique ID',
   `name` varchar(255) NOT NULL COMMENT 'Descriptive name',
-  `sortorder` tinyint(1) unsigned NOT NULL default '0' COMMENT 'Where to sort this category on the scoreboard',
-  `color` varchar(25) default NULL COMMENT 'Background colour on the scoreboard',
-  `visible` tinyint(1) unsigned NOT NULL default '1' COMMENT 'Are teams in this category visible?',
+  `sortorder` tinyint(1) unsigned NOT NULL DEFAULT '0' COMMENT 'Where to sort this category on the scoreboard',
+  `color` varchar(25) DEFAULT NULL COMMENT 'Background colour on the scoreboard',
+  `visible` tinyint(1) unsigned NOT NULL DEFAULT '1' COMMENT 'Are teams in this category visible?',
   PRIMARY KEY  (`categoryid`),
   KEY `sortorder` (`sortorder`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='Categories for teams (e.g.: participants, observers, ...)';
@@ -336,9 +337,9 @@ CREATE TABLE `team_category` (
 --
 
 CREATE TABLE `team_unread` (
-  `teamid` varchar(15) NOT NULL default '' COMMENT 'Team login',
-  `mesgid` int(4) unsigned NOT NULL default '0' COMMENT 'Clarification ID',
-  `type` varchar(25) NOT NULL default 'clarification' COMMENT 'Type of message (now always "clarification")',
+  `teamid` varchar(15) NOT NULL DEFAULT '' COMMENT 'Team login',
+  `mesgid` int(4) unsigned NOT NULL DEFAULT '0' COMMENT 'Clarification ID',
+  `type` varchar(25) NOT NULL DEFAULT 'clarification' COMMENT 'Type of message (now always "clarification")',
   PRIMARY KEY (`teamid`,`type`,`mesgid`),
   KEY `mesgid` (`mesgid`),
   CONSTRAINT `team_unread_ibfk_1` FOREIGN KEY (`teamid`) REFERENCES `team` (`login`) ON DELETE CASCADE,
@@ -350,14 +351,14 @@ CREATE TABLE `team_unread` (
 --
 
 CREATE TABLE `testcase` (
-  `testcaseid` int(4) unsigned NOT NULL auto_increment COMMENT 'Unique identifier',
-  `md5sum_input` char(32) default NULL COMMENT 'Checksum of input data',
-  `md5sum_output` char(32) default NULL COMMENT 'Checksum of output data',
+  `testcaseid` int(4) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Unique identifier',
+  `md5sum_input` char(32) DEFAULT NULL COMMENT 'Checksum of input data',
+  `md5sum_output` char(32) DEFAULT NULL COMMENT 'Checksum of output data',
   `input` longblob COMMENT 'Input data',
   `output` longblob COMMENT 'Output data',
   `probid` varchar(8) NOT NULL COMMENT 'Corresponding problem ID',
   `rank` int(4) NOT NULL COMMENT 'Determines order of the testcases in judging',
-  `description` varchar(255) default NULL COMMENT 'Description of this testcase',
+  `description` varchar(255) DEFAULT NULL COMMENT 'Description of this testcase',
   PRIMARY KEY  (`testcaseid`),
   UNIQUE KEY `rank` (`probid`,`rank`),
   KEY `probid` (`probid`),
