@@ -1,9 +1,12 @@
-# $Id: test-hello.sh 3602 2011-08-17 12:57:40Z eldering $
-#
 # This should give CORRECT on the default problem 'hello'.
 #
 # @EXPECTED_RESULTS@: CORRECT
 
+if [ -z "$DOMJUDGE" -o -z "$ONLINE_JUDGE" ]; then
+	echo "Variable DOMJUDGE and/or ONLINE_JUDGE not defined."
+	exit 1
+fi
+
 echo "Hello world!"
 
 exit 0
