@@ -103,7 +103,6 @@ function checkUploadForm()
 	var langelt = document.getElementById("langid");
 	var language = langelt.options[langelt.selectedIndex].value;
 	var languagetxt = langelt.options[langelt.selectedIndex].text;
-	var filebut = document.getElementById("codebutton");
 	var fileelt = document.getElementById("maincode");
 	var filename = fileelt.value;
 	var probelt = document.getElementById("probid");
@@ -112,7 +111,7 @@ function checkUploadForm()
 	var auxfiles = document.getElementsByName("code[]");
 
 	var error = false;
-	langelt.className = probelt.className = filebut.className = "";
+	langelt.className = probelt.className = "";
 	if ( language == "" ) {
 		langelt.focus();
 		langelt.className = "errorfield";
@@ -124,7 +123,6 @@ function checkUploadForm()
 		error = true;
 	}
 	if ( filename == "" ) {
-		filebut.className = "errorfield";
 		return false;
 	}
 
@@ -153,20 +151,15 @@ function checkUploadForm()
 
 }
 
-function resetUploadForm(refreshtime) {
-	var filebut = document.getElementById("codebutton");
+function resetUploadForm(refreshtime, maxfiles) {
 	var addfile = document.getElementById("addfile");
 	var auxfiles = document.getElementById("auxfiles");
-	var selecttext = "Select file...";
-	filebut.value = selecttext;
 	addfile.disabled = true;
 	auxfiles.innerHTML = "";
 	doReload = true;
 	setTimeout('reloadPage()', refreshtime * 1000);
 }
 
-var W3CDOM = (document.createElement && document.getElementsByTagName);
-
 var doReload = true;
 
 function reloadPage()
@@ -183,43 +176,20 @@ function initReload(refreshtime)
 	setTimeout('reloadPage()', refreshtime * 1000);
 }
 
-function initFileUploads() {
-	if (!W3CDOM) return;
-	var selecttext = "Select file...";
-	var fakeFileUpload = document.createElement('span');
-	fakeFileUpload.className = 'fakefile';
-	var input = document.createElement('input');
-	input.type = 'button';
-	input.value = selecttext;
-	input.id = "codebutton";
-	fakeFileUpload.appendChild(input);
-	var x = document.getElementsByTagName('input');
-	for (var i=0;i<x.length;i++) {
-		if (x[i].type != 'file') continue;
-		if (x[i].parentNode.className != 'fileinputs') continue;
-		x[i].className = 'file hidden';
-		var clone = fakeFileUpload.cloneNode(true);
-		x[i].parentNode.appendChild(clone);
-		x[i].relatedElement = clone.getElementsByTagName('input')[0];
-		// stop refresh when clicking a button.
-		x[i].onclick = function() { doReload = false; }
-		x[i].onchange = x[i].onmouseout = function () {
-			if ( this.value == "" ) {
-				this.relatedElement.value = selecttext;
-			} else {
-				var filename = this.value;
-				// Opera prepends a fake fs path: C:\fakepath\. Strip that.
-				var fake = "fakepath\\";
-				if ( filename.indexOf(fake) >= 0 ) {
-					filename = filename.substr(filename.lastIndexOf(fake)+fake.length);
-				}
-				// some other browsers (Konqueror at least) may prepend the full FS path
-				if ( filename.indexOf(File.separator) >= 0 ) {
-					filename = filename.substr(filename.lastIndexOf(File.separator)+1);
-				}
-				detectProblemLanguage(filename);
-				this.relatedElement.value = filename;
-			}
+function initFileUploads(maxfiles) {
+	var fileelt = document.getElementById("maincode");
+
+	if ( maxfiles > 1 ) {
+		var fileadd = document.getElementById("addfile");
+		var supportshtml5multi = ("multiple" in fileelt);
+		if ( supportshtml5multi ) {
+			fileadd.style.display = "none";
+		}
+	}
+	fileelt.onclick = function() { doReload = false; }
+	fileelt.onchange = fileelt.onmouseout = function () {
+		if ( this.value != "" ) {
+			detectProblemLanguage(this.value);
 		}
 	}
 }
@@ -237,7 +207,6 @@ function addFileUpload() {
 	var input = document.createElement('input');
 	input.type = 'file';
 	input.name = 'code[]';
-	input.size = '50';
 	var br = document.createElement('br');
 
 	document.getElementById('auxfiles').appendChild( input );
@@ -253,3 +222,190 @@ function togglelastruns() {
 		}
 	}
 }
+
+function updateClock()
+{	
+	curtime = initial+offset;
+	date.setTime(curtime*1000);
+
+	var fmt = "";
+	if (curtime >= starttime && curtime < endtime ) {
+		var left = endtime - curtime;
+		var what = "time left: ";
+	} else if (curtime >= activatetime && curtime < starttime ) {
+		var left = starttime - curtime;
+		var what = "time to start: ";
+	} else {
+		var left = 0;
+		var what = "";
+	}
+
+	if ( left ) {
+		if ( left > 24*60*60 ) {
+			d = Math.floor(left/(24*60*60));
+			fmt += d + "d ";
+			left -= d * 24*60*60;
+		}
+		if ( left > 60*60 ) {
+			h = Math.floor(left/(60*60));
+			fmt += h + ":";
+			left -= h * 60*60;
+		} 
+		m = Math.floor(left/60);
+		if ( m < 10 ) { fmt += "0"; }
+		fmt += m + ":";
+		left -= m * 60;
+		if ( left < 10 ) { fmt += "0"; }
+		fmt += left;
+	}
+
+	timecurelt.innerHTML = date.toString().replace(/(\w{3})\ (\w{3})\ (\d{2})\ (\d{4})\ (\d{2}:\d{2}:\d{2}).*\((\w+)\)/, "$1 $3 $2 $4 $5 $6");
+	timeleftelt.innerHTML = what + fmt;
+	offset++;
+}
+
+function setCookie(name, value) {
+	var expire = new Date();
+	expire.setDate(expire.getDate() + 3); // three days valid
+	document.cookie = name + "=" + escape(value) + "; expires=" + expire.toUTCString();
+}
+
+function getCookie(name) {
+	var cookies = document.cookie.split(";");
+	for (var i = 0; i < cookies.length; i++) {
+		var idx = cookies[i].indexOf("=");
+		var key = cookies[i].substr(0, idx);
+		var value = cookies[i].substr(idx+1);
+		key = key.replace(/^\s+|\s+$/g,""); // trim
+		if (key == name) {
+			return unescape(value);
+		}
+	}
+	return "";
+}
+
+function getSelectedTeams() {
+	var cookieVal = getCookie("dj_teamselection");
+	if (cookieVal == null || cookieVal == "") {
+		return new Array();
+	}
+	return JSON.parse(cookieVal);
+}
+
+function getScoreboard() {
+	var scoreboard = document.getElementsByClassName("scoreboard");
+	if (scoreboard == null || scoreboard[0] == null) {
+		return null;
+	}
+	return scoreboard[0].rows;
+}
+
+function getRank(row) {
+	return row.getElementsByTagName("td")[0];
+}
+
+function getTeamname(row) {
+	return row.getElementsByTagName("td")[2];
+}
+
+function toggle(id, show) {
+	var scoreboard = getScoreboard();
+
+	var favTeams = getSelectedTeams();
+	// count visible favourite teams (if filtered)
+	var visCnt = 0;
+	for (var i = 0; i < favTeams.length; i++) {
+		for (var j = 0; j < scoreboard.length; j++) {
+			var scoreTeamname = getTeamname(scoreboard[j]);
+			if (scoreTeamname == null) {
+				continue;
+			}
+			if (scoreTeamname.innerHTML == favTeams[i]) {
+				visCnt++;
+				break;
+			}
+		}
+	}
+	var teamname = getTeamname(scoreboard[id + visCnt]).innerHTML;
+	if (show) {
+		favTeams[favTeams.length] = teamname;
+	} else {
+		// copy all other teams
+		var newFavTeams = new Array();
+		for (var i = 0; i < favTeams.length; i++) {
+			if (favTeams[i] != teamname) {
+				newFavTeams[newFavTeams.length] = favTeams[i];
+			}
+		}
+		favTeams = newFavTeams;
+	}
+
+	var cookieVal = JSON.stringify(favTeams);
+	setCookie("dj_teamselection", cookieVal);
+
+	window.location.reload();
+}
+
+function addHeart(rank, row, id, isFav) {
+	var firstCol = getRank(row);
+	var color = isFav ? "red" : "gray";
+	return "<span style=\"cursor:pointer;color:" + color + ";\" onclick=\"toggle(" + id + "," + (isFav ? "false" : "true") + ")\">&#9829;</span>" + firstCol.innerHTML;
+}
+
+function initFavouriteTeams() {
+	var scoreboard = getScoreboard();
+	if (scoreboard == null) {
+		return;
+	}
+
+	var favTeams = getSelectedTeams();
+	var toAdd = new Array();
+	var cntFound = 0;
+	var lastRank = 0;
+	for (var j = 0; j < scoreboard.length - 1; j++) {
+		var found = false;
+		var teamname = getTeamname(scoreboard[j]);
+		if (teamname == null) {
+			continue;
+		}
+		var firstCol = getRank(scoreboard[j]);
+		var rank = firstCol.innerHTML;
+		for (var i = 0; i < favTeams.length; i++) {
+			if (teamname.innerHTML == favTeams[i]) {
+				found = true;
+				firstCol.innerHTML = addHeart(rank, scoreboard[j], j, found);
+				toAdd[cntFound] = scoreboard[j].cloneNode(true);
+				if (rank == "") {
+					// make rank explicit in case of tie
+					getRank(toAdd[cntFound]).innerHTML += lastRank;
+				}
+				scoreboard[j].style.background = "lightyellow";
+				cntFound++;
+				break;
+			}
+		}
+		if (!found) {
+			firstCol.innerHTML = addHeart(rank, scoreboard[j], j, found);
+		}
+		if (rank != "") {
+			lastRank = rank;
+		}
+	}
+
+	// copy favourite teams to the top of the scoreboard
+	for (var i = 0; i < cntFound; i++) {
+		var copy = toAdd[i];
+		var firstCol = getRank(copy);
+		var color = "red";
+		var style = "";
+		if (i == 0) {
+			style += "border-top: 2px solid black;";
+		}
+		if (i == cntFound - 1) {
+			style += "border-bottom: thick solid black;";
+		}
+		copy.setAttribute("style", style);
+		var tbody = scoreboard[1].parentNode;
+		tbody.insertBefore(copy, scoreboard[i + 1]);
+	}
+}
