@@ -68,7 +68,7 @@ echo addHidden('cmd', $cmd) .
 	addHidden('table','contest') .
 	addHidden('referrer', @$_GET['referrer'] . ( $cmd == 'edit'?(strstr(@$_GET['referrer'],'?') === FALSE?'?edited=1':'&edited=1'):'')) .
 	addSubmit('Save') .
-	addSubmit('Cancel', 'cancel', null, true, 'formnovalidate formaction="' . htmlspecialchars($_GET['referrer']) . '"') .
+	addSubmit('Cancel', 'cancel', null, true, 'formnovalidate' . (isset($_GET['referrer']) ? ' formaction="' . htmlspecialchars($_GET['referrer']) . '"':'')) .
 	addEndForm();
 
 require(LIBWWWDIR . '/footer.php');
