@@ -12,7 +12,7 @@ require(LIBWWWDIR . '/header.php');
 echo "<h1>DOMjudge Jury interface</h1>\n\n";
 
 if ( is_readable('../images/DOMjudgelogo.png') ) {
-	echo "<p><a href=\"http://domjudge.sourceforge.net/\">" .
+	echo "<p><a href=\"http://www.domjudge.org/\">" .
 		"<img src=\"../images/DOMjudgelogo.png\" id=\"djlogo\" " .
 		"alt=\"DOMjudge logo\" title=\"The DOMjudge logo: free as in beer!\" /></a></p>\n\n";
 }
