@@ -12,27 +12,19 @@ if (empty($_SERVER['REMOTE_USER']) || $_SERVER['AUTH_TYPE'] != "Basic") {
 	die("Authentication not enabled, check webserver config");
 }
 
-define('IS_JURY', TRUE);
-
 require_once('../configure.php');
 
-if( DEBUG & DEBUG_TIMINGS ) {
-	require_once(LIBDIR . '/lib.timer.php');
-}
+define('IS_JURY', TRUE);
+define('IS_PUBLIC', false);
 
-require_once(LIBDIR . '/lib.error.php');
-require_once(LIBDIR . '/lib.misc.php');
-require_once(LIBDIR . '/lib.dbconfig.php');
-require_once(LIBDIR . '/use_db.php');
+require_once(LIBDIR . '/init.php');
 
-parseLangExts();
-
-set_exception_handler('exception_handler');
 setup_database_connection();
 
 require_once(LIBWWWDIR . '/common.php');
 require_once(LIBWWWDIR . '/print.php');
 require_once(LIBWWWDIR . '/forms.php');
+require_once(LIBWWWDIR . '/printing.php');
 
 require_once(LIBWWWDIR . '/validate.jury.php');
 require_once(LIBWWWDIR . '/common.jury.php');
