@@ -15,11 +15,20 @@ if ( ! $id || ! preg_match("/^[A-Za-z0-9_\-.]*$/", $id)) {
 	error("Missing or invalid judge hostname");
 }
 
-if ( IS_ADMIN && isset($_POST['cmd']) &&
-	( $_POST['cmd'] == 'activate' || $_POST['cmd'] == 'deactivate' ) ) {
+if ( isset($_REQUEST['cmd']) &&
+	( $_REQUEST['cmd'] == 'activate' || $_REQUEST['cmd'] == 'deactivate' ) ) {
+
+	requireAdmin();
+
 	$DB->q('UPDATE judgehost SET active = %i WHERE hostname = %s',
-	       ($_POST['cmd'] == 'activate' ? 1 : 0), $id);
-	auditlog('judgehost', $id, 'marked ' . ($_POST['cmd']=='activate'?'active':'inactive'));
+	       ($_REQUEST['cmd'] == 'activate' ? 1 : 0), $id);
+	auditlog('judgehost', $id, 'marked ' . ($_REQUEST['cmd']=='activate'?'active':'inactive'));
+
+	// the request came from the overview page
+	if ( isset($_GET['cmd']) ) {
+		header("Location: judgehosts.php");
+		exit;
+	}
 }
 
 $row = $DB->q('TUPLE SELECT * FROM judgehost WHERE hostname = %s', $id);
@@ -33,9 +42,9 @@ echo "<h1>Judgehost ".printhost($row['hostname'])."</h1>\n\n";
 ?>
 
 <table>
-<tr><td scope="row">Name:  </td><td><?php echo printhost($row['hostname'], TRUE)?></td></tr>
-<tr><td scope="row">Active:</td><td><?php echo printyn($row['active'])?></td></tr>
-<tr><td scope="row">Status:</td><td>
+<tr><td>Name:  </td><td><?php echo printhost($row['hostname'], TRUE)?></td></tr>
+<tr><td>Active:</td><td><?php echo printyn($row['active'])?></td></tr>
+<tr><td>Status:</td><td>
 <?php
 if ( empty($row['polltime']) ) {
 	echo "Judgehost never checked in.";
@@ -108,8 +117,8 @@ if( $res->count() == 0 ) {
 		echo "<td><a$link>" . printtime($jud['starttime']) . '</a></td>';
 		echo "<td><a$link>" . $runtime . '</a></td>';
 		echo "<td><a$link>" . printresult(@$jud['result'], $jud['valid']) . '</a></td>';
-		echo "<td align=\"center\"><a$link>" . printyn($jud['valid']) . '</a></td>';
-		echo "<td align=\"center\"><a$link>" . printyn($jud['verified']) . '</a></td>';
+		echo "<td class=\"tdcenter\"><a$link>" . printyn($jud['valid']) . '</a></td>';
+		echo "<td class=\"tdcenter\"><a$link>" . printyn($jud['verified']) . '</a></td>';
 		echo "</tr>\n";
 	}
 	echo "</tbody>\n</table>\n\n";
