@@ -1,4 +1,4 @@
-<div id="menutop">
+<nav><div id="menutop">
 <a href="index.php" accesskey="h">home</a>
 <a href="problems.php" accesskey="p">problems</a>
 <?php	if ( IS_ADMIN ) { ?>
@@ -11,6 +11,9 @@
 <a href="clarifications.php" accesskey="c" id="menu_clarifications">clarifications</a>
 <?php	} ?>
 <a href="submissions.php" accesskey="s">submissions</a>
+<?php   if ( have_printing() ) { ?>
+<a href="print.php" accesskey="p">print</a>
+<?php   } ?>
 <a href="scoreboard.php" accesskey="b">scoreboard</a>
 </div>
 
@@ -29,4 +32,4 @@ if ( isset($refresh) ) {
 	    addEndForm() . "</div>\n";
 }
 
-echo "</div>\n";
+echo "</div></nav>\n";
