@@ -14,7 +14,8 @@ require(LIBWWWDIR . '/header.php');
 echo "<h1>Problems</h1>\n\n";
 
 // Select all data, sort problems from the current contest on top.
-$res = $DB->q('SELECT p.*, c.*, COUNT(testcaseid) AS testcases
+$res = $DB->q('SELECT p.probid,p.name,p.allow_submit,p.allow_judge,p.timelimit,p.color,
+               p.problemtext_type, c.*, COUNT(testcaseid) AS testcases
                FROM problem p
                NATURAL JOIN contest c
                LEFT JOIN testcase USING (probid)
@@ -24,14 +25,16 @@ if( $res->count() == 0 ) {
 	echo "<p class=\"nodata\">No problems defined</p>\n\n";
 } else {
 	echo "<table class=\"list sortable\">\n<thead>\n" .
-		"<tr><th scope=\"col\">ID</th><th scope=\"col\">name</th>" .
-		"<th scope=\"col\" class=\"sorttable_numeric\">contest</th>" .
-	        "<th scope=\"col\">allow<br />submit</th>" .
-		"<th scope=\"col\">allow<br />judge</th>" .
-		"<th scope=\"col\">time<br />limit</th>" .
-		"<th class=\"sorttable_nosort\" scope=\"col\">colour</th>" .
-	    "<th scope=\"col\">test<br />cases</th>" .
-		"</tr></thead>\n<tbody>\n";
+	     "<tr><th scope=\"col\">ID</th><th scope=\"col\">name</th>" .
+	     "<th scope=\"col\" class=\"sorttable_numeric\">contest</th>" .
+	     "<th scope=\"col\">allow<br />submit</th>" .
+	     "<th scope=\"col\">allow<br />judge</th>" .
+	     "<th scope=\"col\">time<br />limit</th>" .
+	     "<th class=\"sorttable_nosort\" scope=\"col\">colour</th>" .
+	     "<th scope=\"col\">test<br />cases</th>" .
+	     "<th scope=\"col\"></th>" .
+	    ( IS_ADMIN ? "<th scope=\"col\"></th>" : '' ) .
+	     "</tr></thead>\n<tbody>\n";
 
 	$lastcid = -1;
 
@@ -50,9 +53,9 @@ if( $res->count() == 0 ) {
 			"</td><td>" . $link . htmlspecialchars($row['name'])."</a>".
 			"</td><td title=\"".htmlspecialchars($row['contestname'])."\">".
 			$link . 'c' . htmlspecialchars($row['cid']) . "</a>" .
-			"</td><td align=\"center\">" . $link .
+			"</td><td class=\"tdcenter\">" . $link .
 			printyn($row['allow_submit']) . "</a>" .
-			"</td><td align=\"center\">" . $link .
+			"</td><td class=\"tdcenter\">" . $link .
 			printyn($row['allow_judge']) . "</a>" .
 			"</td><td>" . $link . (int)$row['timelimit'] . "</a>" .
 			"</td>".
@@ -63,16 +66,24 @@ if( $res->count() == 0 ) {
 		      ';" alt="problem colour ' . htmlspecialchars($row['color']) .
 		      '" src="../images/circle.png" /></a>'
 			: '<td>' . $link . '&nbsp;</a>' );
-			if ( IS_ADMIN ) {
-				echo "</td><td><a href=\"testcase.php?probid=" . $row['probid'] .
-				    "\">" . $row['testcases'] . "</a></td>" .
-				    '<td><a href="export.php?id=' . urlencode($row['probid']) .
-				    '"><img src="../images/b_save.png" /></a></td>' .
-				    "<td class=\"editdel\">" .
-					editLink('problem', $row['probid']) . " " .
-					delLink('problem','probid',$row['probid']);
-			}
-			echo "</td></tr>\n";
+		echo "</td><td><a href=\"testcase.php?probid=" . $row['probid'] .
+		    "\">" . $row['testcases'] . "</a></td>";
+		if ( !empty($row['problemtext_type']) ) {
+			echo '<td title="view problem description">' .
+			     '<a href="problem.php?id=' . urlencode($row['probid']) .
+			     '&amp;cmd=viewtext"><img src="../images/' . urlencode($row['problemtext_type']) .
+			     '.png" alt="problem text" /></a></td>';
+		} else {
+			echo '<td></td>';
+		}
+		if ( IS_ADMIN ) {
+			echo '<td title="export problem as zip-file">' .
+			     exportLink($row['probid']) . '</td>' .
+			     "<td class=\"editdel\">" .
+			     editLink('problem', $row['probid']) . " " .
+			     delLink('problem','probid',$row['probid']) . "</td>";
+		}
+		echo "</tr>\n";
 	}
 	echo "</tbody>\n</table>\n\n";
 }
@@ -81,9 +92,8 @@ if ( IS_ADMIN ) {
 	echo "<p>" . addLink('problem') . "</p>\n\n";
 	if ( class_exists("ZipArchive") ) {
 		echo "\n" . addForm('problem.php', 'post', null, 'multipart/form-data') .
-	 		addHidden('id', @$data['probid']) .
-	 		'Problem archive: ' .
-	 		addFileField('problem_archive') .
+	 		'Problem archive(s): ' .
+	 		addFileField('problem_archive[]', null, ' required multiple accept="application/zip"') .
 	 		addSubmit('Upload', 'upload') .
 	 		addEndForm() . "\n";
 	}
