@@ -9,23 +9,14 @@
 require_once('../configure.php');
 
 define('IS_JURY', false);
+define('IS_PUBLIC', true);
 
-if( DEBUG & DEBUG_TIMINGS ) {
-	require_once(LIBDIR . '/lib.timer.php');
-}
+require_once(LIBDIR . '/init.php');
 
-require_once(LIBDIR . '/lib.error.php');
-require_once(LIBDIR . '/lib.misc.php');
-require_once(LIBDIR . '/lib.dbconfig.php');
-require_once(LIBDIR . '/use_db.php');
-
-parseLangExts();
-
-set_exception_handler('exception_handler');
 setup_database_connection();
 
 require_once(LIBWWWDIR . '/common.php');
 require_once(LIBWWWDIR . '/print.php');
 
 $cdata = getCurContest(TRUE);
-$cid = $cdata['cid'];
+$cid = (int)$cdata['cid'];
